aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/core/hw/gpu.h
diff options
context:
space:
mode:
authorGravatar Subv <subv2112@gmail.com>2015-03-14 14:40:40 -0500
committerGravatar Subv <subv2112@gmail.com>2015-03-14 15:26:42 -0500
commitfb8f47060bb9c7d6b77824a50782e05b37ad0281 (patch)
treea8aa4a3e4e59265b56ed550d8adcd48e420c2745 /src/core/hw/gpu.h
parented5b275d21612906e6eeb4b1f344aa0f1eb31c10 (diff)
GPU: Implemented the flip_data (bit 0) bit in display transfers.
Diffstat (limited to 'src/core/hw/gpu.h')
-rw-r--r--src/core/hw/gpu.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/core/hw/gpu.h b/src/core/hw/gpu.h
index 5b7f0a4e..e8552d85 100644
--- a/src/core/hw/gpu.h
+++ b/src/core/hw/gpu.h
@@ -191,7 +191,7 @@ struct Regs {
union {
u32 flags;
- BitField< 0, 1, u32> flip_data; // flips input data horizontally (TODO) if true
+ BitField< 0, 1, u32> flip_vertically; // flips input data vertically
BitField< 1, 1, u32> output_tiled; // Converts from linear to tiled format
BitField< 3, 1, u32> raw_copy; // Copies the data without performing any processing
BitField< 8, 3, PixelFormat> input_format;